AnimationGraphicalObjectBuildProperties

Enum AnimationGraphicalObjectBuildProperties 

pub enum AnimationGraphicalObjectBuildProperties {
    BuildDiagram(AnimationDgmBuildProperties),
    BuildChart(AnimationChartBuildProperties),
}

Variants



BuildDiagram(AnimationDgmBuildProperties)

This element specifies how to build the animation for a diagram.

Xml example

Consider having a diagram appear as on entity as opposed to by section. The bldDgm element should be used as follows:

<p:bdldLst>
  <p:bldGraphic spid="4" grpId="0">
    <p:bldSub>
      <a:bldDgm bld="one"/>
    </p:bldSub>
  </p:bldGraphic>
</p:bldLst>


BuildChart(AnimationChartBuildProperties)

This element specifies how to build the animation for a diagram.

Xml example

Consider the following example where a chart is specified to be animated by category rather than as one entity. Thus, the bldChart element should be used as follows:

<p:bdldLst>
  <p:bldGraphic spid="4" grpId="0">
    <p:bldSub>
      <a:bldChart bld="category"/>
    </p:bldSub>
  </p:bldGraphic>
</p:bldLst>