pub struct LineEndProperties {
pub end_type: Option<LineEndType>,
pub width: Option<LineEndWidth>,
pub length: Option<LineEndLength>,
}Fields
end_type: Option<LineEndType>Specifies the line end decoration, such as a triangle or arrowhead.
width: Option<LineEndWidth>Specifies the line end width in relation to the line width.
length: Option<LineEndLength>Specifies the line end length in relation to the line width.
Implementations
Sourceimpl LineEndProperties
impl LineEndProperties
pub fn from_xml_element(xml_node: &XmlNode) -> Result<LineEndProperties>