pub enum CompoundLine {
Single,
Double,
ThickThin,
ThinThick,
Triple,
}Expand description
This simple type specifies the compound line type that is to be used for lines with text such as underlines.
Variants
Single
Single line: one normal width
Double
Double lines of equal width
ThickThin
Double lines: one thick, one thin
ThinThick
Double lines: one thin, one thick
Triple
Three lines: thin, thick, thin