pub enum TextFontAlignType {
Auto,
Top,
Center,
Baseline,
Bottom,
}Expand description
This simple type specifies the different kinds of font alignment.
Variants
Auto
When the text flow is horizontal or simple vertical same as fontBaseline but for other vertical modes same as fontCenter.
Top
The letters are anchored to the top baseline of a single line.
Center
The letters are anchored between the two baselines of a single line.
Baseline
The letters are anchored to the bottom baseline of a single line.
Bottom
The letters are anchored to the very bottom of a single line. This is different than the bottom baseline because of letters such as “g,” “q,” “y,” etc.