TextBullet

Enum TextBullet 

pub enum TextBullet {
    None,
    AutoNumbered(TextAutonumberedBullet),
    Character(String),
    Picture(Box<Blip>),
}

Variants



None

This element specifies that the paragraph within which it is applied is to have no bullet formatting applied to it. That is to say that there should be no bulleting found within the paragraph where this element is specified.

Xml example

<p:txBody>
  …
  <a:p>
    <a:pPr …>
      <a:buNone/>
    </a:pPr>
    …
    <a:t>Bullet 1</a:t>
    …
  </a:p>
  …
</p:txBody>

The above paragraph is formatted with no bullets.



AutoNumbered(TextAutonumberedBullet)

This element specifies that automatic numbered bullet points should be applied to a paragraph. These are not just numbers used as bullet points but instead automatically assigned numbers that are based on both buAutoNum attributes and paragraph level.

Xml example

<p:txBody>
  …
  <a:p>
    <a:pPr …>
      <a:buAutoNum type="arabicPeriod"/>
    </a:pPr>
    …
    <a:t>Bullet 1</a:t>
    …
  </a:p>
  <a:p>
    <a:pPr lvl="1"…>
      <a:buAutoNum type="arabicPeriod"/>
    </a:pPr>
    …
    <a:t>Bullet 2</a:t>
    …
  </a:p>
  <a:p>
    <a:pPr …>
      <a:buAutoNum type="arabicPeriod"/>
    </a:pPr>
    …
    <a:t>Bullet 3</a:t>
    …
  </a:p>
  …
</p:txBody>

For the above text there are a total of three bullet points. Two of which are at lvl=“0” and one at lvl=“1”. Due to this breakdown of levels, the numbering sequence that should be automatically applied is 1, 1, 2 as is shown in the picture above.



Character(String)

This element specifies that a character be applied to a set of bullets. These bullets are allowed to be any character in any font that the system is able to support. If no bullet font is specified along with this element then the paragraph font is used.

Xml example

<p:txBody>
  …
  <a:p>
    <a:pPr …>
      <a:buFont typeface="Calibri"/>
      <a:buChar char="g"/>
    </a:pPr>
    …
    <a:t>Bullet 1</a:t>
    …
  </a:p>
  <a:p>
    <a:pPr lvl="1"…>
      <a:buFont typeface="Calibri"/>
      <a:buChar char="g"/>
    </a:pPr>
    …
    <a:t>Bullet 2</a:t>
    …
  </a:p>
  <a:p>
    <a:pPr …>
      <a:buFont typeface="Calibri"/>
      <a:buChar char="g"/>
    </a:pPr>
    …
    <a:t>Bullet 3</a:t>
    …
  </a:p>
  …
</p:txBody>

For the above text there are a total of three bullet points. Two of which are at lvl=“0” and one at lvl=“1”. Because the same character is specified for each bullet the levels do not stand out here. The only difference is the indentation as shown in the picture above.



Picture(Box<Blip>)

This element specifies that a picture be applied to a set of bullets. This element allows for any standard picture format graphic to be used instead of the typical bullet characters. This opens up the possibility for bullets to be anything the generating application would seek to apply.

Xml example

<p:txBody>
  …
  <a:p>
    <a:pPr …>
      <a:buBlip>
        <a:blip r:embed="rId2"/>
      </a:buBlip>
    </a:pPr>
    …
    <a:t>Bullet 1</a:t>
    …
  </a:p>
  <a:p>
    <a:pPr lvl="1"…>
      <a:buBlip>
        <a:blip r:embed="rId2"/>
      </a:buBlip>
    </a:pPr>
    …
    <a:t>Bullet 2</a:t>
    …
  </a:p>
  <a:p>
    <a:pPr …>
      <a:buBlip>
        <a:blip r:embed="rId2"/>
      </a:buBlip>
    </a:pPr>
    …
    <a:t>Bullet 3</a:t>
    …
  </a:p>
  …
</p:txBody>

For the above text there are a total of three bullet points. Two of which are at lvl=“0” and one at lvl=“1”. Because the same picture is specified for each bullet the levels do not stand out here. The only difference is the indentation as shown in the picture above.