pub enum AnimationGraphicalObjectBuildProperties {
BuildDiagram(AnimationDgmBuildProperties),
BuildChart(AnimationChartBuildProperties),
}Variants
BuildDiagram(AnimationDgmBuildProperties)
This element specifies how to build the animation for a diagram.
Xml example
Consider having a diagram appear as on entity as opposed to by section. The bldDgm element should be used as follows:
<p:bdldLst>
<p:bldGraphic spid="4" grpId="0">
<p:bldSub>
<a:bldDgm bld="one"/>
</p:bldSub>
</p:bldGraphic>
</p:bldLst>BuildChart(AnimationChartBuildProperties)
This element specifies how to build the animation for a diagram.
Xml example
Consider the following example where a chart is specified to be animated by category rather than as one entity. Thus, the bldChart element should be used as follows:
<p:bdldLst>
<p:bldGraphic spid="4" grpId="0">
<p:bldSub>
<a:bldChart bld="category"/>
</p:bldSub>
</p:bldGraphic>
</p:bldLst>Trait Implementations
Sourceimpl Clone for AnimationGraphicalObjectBuildProperties
impl Clone for AnimationGraphicalObjectBuildProperties
Sourcefn clone(&self) -> AnimationGraphicalObjectBuildProperties
fn clone(&self) -> AnimationGraphicalObjectBuildProperties
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AnimationGraphicalObjectBuildProperties
impl PartialEq for AnimationGraphicalObjectBuildProperties
Sourcefn eq(&self, other: &AnimationGraphicalObjectBuildProperties) -> bool
fn eq(&self, other: &AnimationGraphicalObjectBuildProperties) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AnimationGraphicalObjectBuildProperties
Sourceimpl XsdChoice for AnimationGraphicalObjectBuildProperties
impl XsdChoice for AnimationGraphicalObjectBuildProperties
fn is_choice_member<T>(name: T) -> bool
Sourcefn try_from_xml_element(
xml_node: &XmlNode,
) -> Option<Result<Self, Box<dyn Error>>>
fn try_from_xml_element( xml_node: &XmlNode, ) -> Option<Result<Self, Box<dyn Error>>>
Tries to parse an XmlNode as a choice member.
None is returned if the XmlNode is not a member of the choice element (implementors should return a boxed
NotGroupMemberError), otherwise Some is returned with the Result of from_xml_element.
Sourceimpl XsdType for AnimationGraphicalObjectBuildProperties
impl XsdType for AnimationGraphicalObjectBuildProperties
fn from_xml_element(xml_node: &XmlNode) -> Result<Self>