pub struct BlurEffect {
pub radius: Option<PositiveCoordinate>,
pub grow: Option<bool>,
}Expand description
This element specifies a blur effect that is applied to the entire shape, including its fill. All color channels, including alpha, are affected.
Fields
radius: Option<PositiveCoordinate>Specifies the radius of blur.
Defaults to 0
grow: Option<bool>Specifies whether the bounds of the object should be grown as a result of the blurring. True indicates the bounds are grown while false indicates that they are not.
With grow set to false, the blur effect does not extend beyond the original bounds of the object
With grow set to true, the blur effect can extend beyond the original bounds of the object
Defaults to true
Implementations
Sourceimpl BlurEffect
impl BlurEffect
pub fn from_xml_element(xml_node: &XmlNode) -> Result<Self>