pub enum TextTabAlignType {
Left,
Center,
Right,
Decimal,
}Expand description
This simple type specifies the text tab alignment types.
Variants
Left
The text at this tab stop is left aligned.
Center
The text at this tab stop is center aligned.
Right
The text at this tab stop is right aligned.
Decimal
At this tab stop, the decimals are lined up. From a user’s point of view, the text here behaves as right aligned until the decimal, and then as left aligned after the decimal.