pub type Guid = String;Expand description
This simple type specifies that its values shall be a 128-bit globally unique identifier (GUID) value.
This simple type’s contents shall match the following regular expression pattern: {[0-9A-F]{8}-[0-9AF]{/// 4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}}.
Aliased Type
pub struct Guid { /* private fields */ }